import {Component, OnInit} from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzModalComponent, NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzImageDirective, NzImageModule} from "ng-zorro-antd/image";
import {NzUploadComponent, NzUploadFile} from "ng-zorro-antd/upload";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {CommonService} from "../../../services/common/common.service";
import {Observable, Observer} from "rxjs";
import {AgentService} from "../../../services/agent/agent.service";
import {DATA} from "../../../data/login/localStorage.namespace";
import {AgentApiService} from "../../../services/agent/agent-api.service";
import {AgentApiAccountComponent} from "../agent-api-account/agent-api-account.component";
@Component({
  selector: 'app-agent-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule,
    AgentApiAccountComponent
  ],
  templateUrl: './agent-list.component.html',
  styleUrl: './agent-list.component.less'
})
export class AgentListComponent {
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;
  // 编辑表单
  editAgentForm: FormGroup;
  editAgentModal = false;
  // 代理商类型
  agentTypeArray = new DictionaryPipe().getDictionaryList('AGENT_TYPE');
  // 代理商API额度充值模态框
  agentApiRechargeModal = false;
  agentApiRechargeForm: FormGroup;
  // 代理商API参数
  agentApiParamModal = false;
  agentApiParamForm: FormGroup;
  // 代理商API交易记录
  currentAgentId: any;
  agentApiRecordModal = false;

  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private agentService: AgentService,
              private agentApiService: AgentApiService,
              private commonService: CommonService,
              private modal: NzModalService) {
    // 初始化搜索框
    this.searchForm = this.fb.group({
      type: [null],
      agentNo: [null],
      agentName: [null],
    });

    this.editAgentForm = this.fb.group({
      agentNo: [null],
      type: ['', [Validators.required]],
      name: ['', [Validators.required]],
      contactsName: ['', [Validators.required]],
      contactsTelephone: ['', [Validators.required]],
      loginName: [''],
    });

    this.agentApiRechargeForm = this.fb.group({
      agentId: [{value: null, disabled: true}],
      agentNo: [{value: null, disabled: true}],
      agentName: [{value: null, disabled: true}],
      currentAmount: [{value: null, disabled: true}],
      amount: [0, [Validators.required]],
    });

    this.agentApiParamForm = this.fb.group({
      agentId: [{value: null, disabled: true}],
      agentNo: [{value: null, disabled: true}],
      agentName: [{value: null, disabled: true}],
      appId: [{value: null, disabled: true}],
      appSecret: [{value: null, disabled: true}],
      merInfoNotify: [null],
      orderRefundNotify: [null],
    });

    // 查询数据
    this.queryData();
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.agentService.queryAgentList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 打开编辑模态框
   */
  showEditAgentModal(data: any) {
    if (data != null) {
      data['type'] = String(data['type']);
      this.editAgentForm.patchValue(data);
      this.editAgentForm.controls['type'].disable();
    }
    this.editAgentModal = true;
  }

  /**
   * 提交数据
   */
  submitData() {
    if (this.editAgentForm.valid) {
      if (this.editAgentForm.controls['agentNo'].value == null) {
        this.agentService.createAgent(this.editAgentForm.value, (data: any) => {
          if (data['return_code'] == '000000') {
            this.message.create('success', '操作成功');
            // 刷新数据
            this.queryData();
            // 关闭弹窗
            this.closeEditModal();
            // 表单重置
            this.editAgentForm.reset();
          } else {
            this.message.create('error', data['return_msg']);
          }
        });
      } else {
        this.agentService.updateAgent(this.editAgentForm.value, (data: any) => {
          if (data['return_code'] == '000000') {
            this.message.create('success', '操作成功');
            // 刷新数据
            this.queryData();
            // 关闭弹窗
            this.closeEditModal();
            // 表单重置
            this.editAgentForm.reset();
          } else {
            this.message.create('error', data['return_msg']);
          }
        });
      }

    } else {
      Object.values(this.editAgentForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭编辑模态框
   */
  closeEditModal() {
    this.editAgentForm.reset();
    this.editAgentForm.controls['agentNo'].setValue(null);
    this.editAgentForm.controls['type'].enable();
    this.editAgentModal = false;
  }

  /**
   * 打开API充值框
   * @param agent
   */
  showApiRecharge(agent: any) {
    this.agentApiService.getAccount({agentId: agent['id']}, (data:any) => {
      if (data['return_code'] == '000000') {
        this.agentApiRechargeForm.patchValue({
          agentId: agent['id'],
          agentNo: agent['agentNo'],
          agentName: agent['name'],
          currentAmount: data['return_data']['amount'],
        });
        this.agentApiRechargeModal = true;
      } else {
        this.message.create('error', data['return_msg']);
      }
    });
  }

  /**
   * api余额充值确认框
   */
  apiRechargeConfirm() {
    if (this.agentApiRechargeForm.valid) {
        this.modal.confirm({
          nzTitle: '充值提醒',
          nzContent: '确认为【' + this.agentApiRechargeForm.controls['agentName'].value + '】代理API余额充值：￥' +this.agentApiRechargeForm.controls['amount'].value + '吗？',
          nzOnOk: () => this.submitApiRecharge()
        });

    } else {
      Object.values(this.agentApiRechargeForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 提交api充值
   */
  submitApiRecharge() {
    const param = {
      agentId: this.agentApiRechargeForm.controls['agentId'].value,
      amount: this.agentApiRechargeForm.controls['amount'].value,
    }
    this.agentApiService.recharge(param, (data: any) => {
      if (data['return_code'] == '000000') {
        this.message.create('success', '操作成功');
        // 刷新数据
        this.queryData();
        // 关闭弹窗
        this.closeApiRecharge();
      } else {
        this.message.create('error', data['return_msg']);
      }
    });
  }

  /**
   * 关闭充值模态框
   */
  closeApiRecharge() {
    this.agentApiRechargeForm.reset();
    this.agentApiRechargeModal = false;
  }


  /**
   * 打开API充值框
   * @param agent
   */
  showApiParam(agent: any) {
    this.agentApiService.getApiParam({agentId: agent['id']}, (data:any) => {
      if (data['return_code'] == '000000') {
        this.agentApiParamForm.patchValue({
          agentId: agent['id'],
          agentNo: agent['agentNo'],
          agentName: agent['name'],
          appId: data['return_data']['appId'],
          appSecret: data['return_data']['appSecret'],
          merInfoNotify: data['return_data']['merInfoNotify'],
          orderRefundNotify: data['return_data']['orderRefundNotify'],
        });
        this.agentApiParamModal = true;
      } else {
        this.message.create('error', data['return_msg']);
      }
    });
  }

  /**
   * 提交api充值
   */
  submitApiParam() {
    const param = {
      agentId: this.agentApiParamForm.controls['agentId'].value,
      merInfoNotify: this.agentApiParamForm.controls['merInfoNotify'].value,
      orderRefundNotify: this.agentApiParamForm.controls['orderRefundNotify'].value,
    }
    this.agentApiService.updateApiParam(param, (data: any) => {
      if (data['return_code'] == '000000') {
        this.message.create('success', '操作成功');
        // 关闭弹窗
        this.closeApiParam();
      } else {
        this.message.create('error', data['return_msg']);
      }
    });
  }

  /**
   * 关闭API参数
   */
  closeApiParam() {
    this.agentApiParamForm.reset();
    this.agentApiParamModal = false;
  }

  /**
   * 展示交易记录
   */
  showRecord(agentId: any) {
    this.currentAgentId = agentId;
    this.agentApiRecordModal = true;
  }

  /**
   * 关闭记录
   */
  closeRecord() {
    this.agentApiRecordModal = false;
  }
}
