import { Component } from '@angular/core';
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {NgForOf, NgIf} from "@angular/common";
import {NzCascaderComponent, NzCascaderModule} from "ng-zorro-antd/cascader";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {
  NzFormControlComponent,
  NzFormDirective,
  NzFormItemComponent,
  NzFormLabelComponent,
  NzFormModule
} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzUploadComponent, NzUploadModule} from "ng-zorro-antd/upload";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzInputDirective, NzInputGroupComponent} from "ng-zorro-antd/input";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {MerService} from "../../../services/merchant/mer.service";
import {MerChainBrandService} from "../../../services/merchant/mer-chain-brand.service";
import {RoleService} from "../../../services/role/role.service";
import {NzMessageService} from "ng-zorro-antd/message";
import {ActivatedRoute} from "@angular/router";
import {HttpClient} from "@angular/common/http";
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzInputNumberComponent} from "ng-zorro-antd/input-number";
import {DeviceService} from "../../../services/device/device.service";
import {DATA} from "../../../data/login/localStorage.namespace";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {NzRadioComponent, NzRadioGroupComponent} from "ng-zorro-antd/radio";

@Component({
  selector: 'app-device-print',
  standalone: true,
  imports: [
    FormsModule,
    NgForOf,
    NzButtonComponent,
    NzColDirective,
    NzFlexDirective,
    NzFormControlComponent,
    NzFormDirective,
    ReactiveFormsModule,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzInputDirective,
    NzSelectComponent,
    NzOptionComponent,
    NzModalModule,
    NzFormModule,
    NzUploadModule,
    NzIconDirective,
    NgIf,
    NzInputGroupComponent,
    NzInputNumberComponent,
    NzCascaderModule,
    NzRadioGroupComponent,
    NzRadioComponent
  ],
  templateUrl: './device-print.component.html',
  styleUrl: './device-print.component.less'
})
export class DevicePrintComponent {
  form: FormGroup;

  constructor(private fb: NonNullableFormBuilder,
              private deviceService: DeviceService,
              private storage: BrowserStorageService,
              private message: NzMessageService,
              private activatedRoute: ActivatedRoute,
              private modal: NzModalService,
              private http: HttpClient) {

    // 初始化表单
    this.form = this.fb.group({
      merNo: [''],
      receiptOutContent: [''],
    });

    let merNo = this.storage.get(DATA)['merchant']['merNo'];
    console.log(merNo);
    if (merNo == null) {
      this.modal.error({
        nzTitle: '提示',
        nzContent: '此功能由油站角色设置',
      });
      return;
    }

    this.deviceService.getSettingReceipt({merNo: merNo}, (data: any) => {
      if (data['return_code'] == '000000') {
        this.form.controls['merNo'].setValue(merNo);
        this.form.controls['receiptOutContent'].setValue(''+data['return_data']);
      }
    });

  }

  /**
   * 提交表单
   */
  submitForm() {
    if (this.form.valid) {
      this.deviceService.settingReceipt(this.form.value, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else {
      Object.values(this.form.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }
}
