import { Component } from '@angular/core';
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {NzColDirective} from "ng-zorro-antd/grid";
import { NzDatePickerModule} from "ng-zorro-antd/date-picker";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {
  NzFormControlComponent,
  NzFormDirective,
  NzFormItemComponent,
  NzFormLabelComponent,
  NzFormModule
} from "ng-zorro-antd/form";
import {NzInputDirective, NzInputGroupComponent} from "ng-zorro-antd/input";
import {NzInputNumberComponent, NzInputNumberGroupComponent} from "ng-zorro-antd/input-number";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {MerService} from "../../../services/merchant/mer.service";
import {DiscountService} from "../../../services/discount/discount.service";
import {NzMessageService} from "ng-zorro-antd/message";
import {ActivatedRoute} from "@angular/router";
import {NzModalModule} from "ng-zorro-antd/modal";
import {NzUploadFile, NzUploadModule} from "ng-zorro-antd/upload";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzCascaderModule} from "ng-zorro-antd/cascader";
import {NzTabsModule} from "ng-zorro-antd/tabs";
import {NzCheckboxModule} from "ng-zorro-antd/checkbox";
import {DiscountPkService} from "../../../services/discount/discount-pk.service";
import {environment} from "../../../../environments/environment";
import {Observable, Observer} from "rxjs";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent,
  NzTbodyComponent, NzTdAddOnComponent,
  NzTheadComponent,
  NzThMeasureDirective, NzThSelectionComponent, NzTrDirective
} from "ng-zorro-antd/table";
import {NzDividerModule} from "ng-zorro-antd/divider";

@Component({
  selector: 'app-discount-pk-edit',
  standalone: true,
  imports: [
    FormsModule,
    NgForOf,
    NzButtonComponent,
    NzColDirective,
    NzFlexDirective,
    NzFormControlComponent,
    NzFormDirective,
    ReactiveFormsModule,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzInputDirective,
    NzSelectComponent,
    NzOptionComponent,
    NzModalModule,
    NzFormModule,
    NzUploadModule,
    NzIconDirective,
    NgIf,
    NzInputGroupComponent,
    NzInputNumberComponent,
    NzCascaderModule,
    NzTabsModule,
    NzCheckboxModule,
    NzDatePickerModule,
    NzInputNumberGroupComponent,
    DatePipe,
    DictionaryPipe,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    NzCellFixedDirective,
    NzTdAddOnComponent,
    NzThSelectionComponent,
    NzDividerModule
  ],
  templateUrl: './discount-pk-edit.component.html',
  styleUrl: './discount-pk-edit.component.less'
})
export class DiscountPkEditComponent {
  BASE_URL = environment.baseUrl;
  FILE_URL = environment.imageUrl;
  listImgLoading = false;
  listImgUrl?: string;

  contentFileList: NzUploadFile[] = [];
  form: FormGroup;

  discountData: any = [];
  checkedDiscountModal = false;
  // 列表中全选状态
  checked = false;
  // 已选择的数据
  setOfCheckedId = new Set<string>();
  // 选中的优惠券数据
  checkedDiscountData: any = [];

  editNumberForm: FormGroup;
  editNumberModal = false;

  constructor(private fb: NonNullableFormBuilder,
              private merService: MerService,
              private discountService: DiscountService,
              private discountPkService: DiscountPkService,
              private message: NzMessageService,
              private activatedRoute: ActivatedRoute) {
    // 初始化表单
    this.form = this.fb.group({
      discountPkNo: [null],
      discountPkName: [null, [Validators.required]],
      salePrice: [null, [Validators.required]],
      describe: [null],
      listImg: [null],
      content: [null],
    });
    // 初始化表单
    this.editNumberForm = this.fb.group({
      discountNo: [{ value: null, disabled: true}, [Validators.required]],
      discountName: [{ value: null, disabled: true}, [Validators.required]],
      number: [null, [Validators.required]],
    });
    // 查询优惠券数据
    this.queryDiscount();

    this.activatedRoute.queryParams.subscribe(queryParams => {
      // 接收到路由参数
      if (queryParams['discountPkNo'] != null) {
        // 查询详情
        this.discountPkService.getDetail({discountPkNo: queryParams['discountPkNo']}, (data: any) => {
          if (data['return_code'] == '000000') {
            const discountData = data['return_data'];
            discountData['discountType'] = String(discountData['discountType']);
            discountData['useScope'] = String(discountData['useScope']).split(',');
            this.form.patchValue(discountData);
          }
        });
      }
    });
  }

  /**
   * 查询优惠券列表
   */
  queryDiscount() {
    this.discountService.queryList({pageNum:1, pageSize:9999, status: 2}, (data: any) => {
      if (data['return_code'] == '000000') {
        this.discountData = data['return_data']['list'];
      }
    });
  }

  showCheckedModal() {
    this.checkedDiscountModal = true;
  }


  closeCheckedModal() {
    this.checkedDiscountModal = false;
  }
  /**
   * 提交选择的优惠券
   */
  submitCheckedDiscount() {
     let array = [];
     for (let discountNo of this.setOfCheckedId) {
       // 优惠券数据是否存在
       let data = this.discountData.find((o: any) => o.discountNo == discountNo);
       if (data != null) {
          // 是否已选择
          let checkedDiscount = this.checkedDiscountData.find((o: any) => o.discountNo == discountNo);
          if (checkedDiscount == null) {
            data['number'] = 1;
          }
          array.push(data);
       }
     }
    this.checkedDiscountData = array;
    this.closeCheckedModal();
  }
  /**
   * 提交表单
   */
  submitForm() {
    if (this.form.controls['useScope'].value == null || this.form.controls['useScope'].value.length == 0) {
      this.message.create('warning', '请选择使用范围');
      return;
    }
    if (this.form.valid) {
      const param = this.form.value;
      param['endTime'] = new Date(this.form.controls['endTime'].value).getTime();
      this.discountPkService.edit(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          if (param['discountNo'] == null) {
            // 清空表单
            this.form.reset();
          }
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else {
      Object.values(this.form.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }


  private getBase64(img: File, callback: (img: string) => void): void {
    const reader = new FileReader();
    reader.addEventListener('load', () => callback(reader.result!.toString()));
    reader.readAsDataURL(img);
  }

  handleChange(info: { file: NzUploadFile }): void {
    switch (info.file.status) {
      case 'uploading':
        this.listImgLoading = true;
        break;
      case 'done':
        // Get this url from response in real world.
        this.getBase64(info.file!.originFileObj!, (img: string) => {
          this.listImgLoading = false;
          this.listImgUrl = img;
        });
        this.form.patchValue({ merLogo: info.file.response['return_data'][0]});
        break;
      case 'error':
        this.message.error('网络错误！');
        this.listImgLoading = false;
        break;
    }
  }

  beforeUpload = (file: NzUploadFile, _fileList: NzUploadFile[]) => {
    return new Observable((observer: Observer<boolean>) => {
      const isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';
      if (!isJpgOrPng) {
        this.message.error('只能上传JPG文件!');
        observer.complete();
        return;
      }
      const isLt2M = file.size! / 1024 / 1024 < 2;
      if (!isLt2M) {
        this.message.error('图片必须小于2MB!');
        observer.complete();
        return;
      }
      observer.next(isJpgOrPng && isLt2M);
      observer.complete();
    });
  };


  updateCheckedSet(discountNo: string, checked: boolean): void {
    if (checked) {
      this.setOfCheckedId.add(discountNo);
    } else {
      this.setOfCheckedId.delete(discountNo);
    }
  }

  /**
   * 单选
   * @param merNo
   * @param checked
   */
  onItemChecked(discountNo: string, checked: boolean): void {
    this.updateCheckedSet(discountNo, checked);
    this.refreshCheckedStatus();
  }

  /**
   * 全选
   * @param checked
   */
  onAllChecked(checked: boolean): void {
    // @ts-ignore
    this.discountData.forEach(({ discountNo }) => this.updateCheckedSet(discountNo, checked));
    this.refreshCheckedStatus();
  }

  /**
   * 刷新数据
   */
  refreshCheckedStatus(): void {
    // @ts-ignore
    this.checked = this.discountData.every(({ discountNo }) => this.setOfCheckedId.has(discountNo));
  }

  /**
   * 修改数量
   * @param data 数据
   */
  showEditNumber(data: any): void {
    this.editNumberForm.patchValue(data);
    this.editNumberModal = true;
  }

  editNumber() {
    if (this.editNumberForm.valid) {
      let data = this.checkedDiscountData.find((o: any) => o.discountNo == this.editNumberForm.controls['discountNo'].value);
      if (data != null) {
        data['number'] = this.editNumberForm.controls['number'].value;
      }
      this.editNumberForm.reset();
      this.editNumberModal = false;
    } else {
      Object.values(this.editNumberForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }

  }
}
