import {Component, Input, OnInit} from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzInputNumberComponent, NzInputNumberModule} from "ng-zorro-antd/input-number";
import {NzModalComponent, NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {DiscountStockService} from "../../../services/discount/discount-stock.service";
import {CommonService} from "../../../services/common/common.service";
import {MerService} from "../../../services/merchant/mer.service";
import {DATA} from "../../../data/login/localStorage.namespace";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {RouterLink} from "@angular/router";
import {NzTypographyComponent} from "ng-zorro-antd/typography";

@Component({
  selector: 'app-discount-stock-code',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule,
    RouterLink,
    NzTypographyComponent
  ],
  templateUrl: './discount-stock-code.component.html',
  styleUrl: './discount-stock-code.component.less'
})
export class DiscountStockCodeComponent implements OnInit {
  @Input() batchNo: any;
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  accountType = null;
  // 搜索表单
  searchForm: FormGroup;
  // 优惠券库存code
  discountStockCodeStatusArray = new DictionaryPipe().getDictionaryList('DISCOUNT_STOCK_CODE_STATUS');
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private discountStockService: DiscountStockService,
              private commonService: CommonService,
              private merService: MerService,
              private modal: NzModalService) {
    this.accountType = this.storage.get(DATA)['account']['objectType'];
    // 初始化搜索框
    this.searchForm = this.fb.group({
      codeId: [''],
      userPhone: [''],
      status: [''],
    });
  }

  ngOnInit(): void {
    // 查询数据
    this.queryData();
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.batchNo = this.batchNo;
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.discountStockService.queryStockBatchCodeList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }
}
