import {Component, Input, OnInit, Output} from '@angular/core';
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {DiscountService} from "../../../services/discount/discount.service";
import {CommonService} from "../../../services/common/common.service";
import {MerService} from "../../../services/merchant/mer.service";
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {DATA} from "../../../data/login/localStorage.namespace";
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {RouterLink} from "@angular/router";
import {NzTypographyComponent} from "ng-zorro-antd/typography";
import {DiscountStockService} from "../../../services/discount/discount-stock.service";
import {DiscountStockCodeComponent} from "../discount-stock-code/discount-stock-code.component";

@Component({
  selector: 'app-discount-stock',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule,
    RouterLink,
    NzTypographyComponent,
    DiscountStockCodeComponent
  ],
  templateUrl: './discount-stock.component.html',
  styleUrl: './discount-stock.component.less'
})
export class DiscountStockComponent implements OnInit{

  @Input() discountNo: any;
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  accountType = null;
  // 搜索表单
  searchForm: FormGroup;
  // 库存
  addStockModal = false;
  addStockForm: FormGroup;

  showCodeModal = false;
  batchNo = null;
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private discountStockService: DiscountStockService,
              private commonService: CommonService,
              private merService: MerService,
              private modal: NzModalService) {
    this.accountType = this.storage.get(DATA)['account']['objectType'];
    // 初始化搜索框
    this.searchForm = this.fb.group({
      batchNo: [''],
    });

    // 初始化搜索框
    this.addStockForm = this.fb.group({
      discountNo: [''],
      stockCount: ['', [Validators.required]],
    });
  }
  ngOnInit(): void {
    // 查询数据
    this.queryData();
  }


  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.discountNo = this.discountNo;
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.discountStockService.queryStockBatchList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 打开增加库存
   */
  showAddStock() {
    this.addStockForm.patchValue({discountNo: this.discountNo});
    this.addStockForm.controls['discountNo'].disable();
    this.addStockModal = true;
  }

  /**
   * 提交库存
   */
  submitStock() {
    if (this.addStockForm.valid) {
      const param = this.addStockForm.value;
      param['discountNo'] = this.discountNo;
      this.discountStockService.addStock(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          this.queryData();
          this.closeAddStock();
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else {
      Object.values(this.addStockForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭增加库存
   */
  closeAddStock() {
    this.addStockForm.reset();
    this.addStockModal = false;
  }

  /**
   * 打开增加库存code
   */
  showStockCode(batchNo: any) {
    this.batchNo = batchNo;
    this.showCodeModal = true;
  }

  /**
   * 关闭增加库存code
   */
  closeStockCode() {
    this.showCodeModal = false;
  }

}


