import { Component } from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzModalComponent, NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {NzMessageService} from "ng-zorro-antd/message";
import {DATA} from "../../../data/login/localStorage.namespace";
import {OilTaskService} from "../../../services/mer-oil-price/oil-task.service";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {CommonService} from "../../../services/common/common.service";

@Component({
  selector: 'app-oil-task',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule
  ],
  templateUrl: './oil-task.component.html',
  styleUrl: './oil-task.component.less'
})
export class OilTaskComponent {
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  accountType = null;
  // 搜索表单
  searchForm: FormGroup;
  // 地区
  regionArray: any = [];
  // 油号
  oilNoArray = new DictionaryPipe().getDictionaryList('OIL_NO');
  // 价格类型
  oilTaskPriceTypeArray = new DictionaryPipe().getDictionaryList('GAS_OIL_TASK_PRICE_TYPE');
  // 执行方式
  oilTaskExecutionTypeArray = new DictionaryPipe().getDictionaryList('GAS_OIL_TASK_EXECUTION_TYPE');
  // 执行状态
  oilTaskStatusArray = new DictionaryPipe().getDictionaryList('GAS_OIL_TASK_STATUS');
  // 价区
  oilPriceZoneArray = new DictionaryPipe().getDictionaryList('OIL_PRICE_ZONE');
  // 编辑任务表单
  editTaskForm: FormGroup;
  editTaskModal = false;
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private oilTaskService: OilTaskService,
              private commonService: CommonService,
              private modal: NzModalService) {
    this.accountType = this.storage.get(DATA)['account']['objectType'];

    // 获取地区
    this.commonService.getRegion('',(data: any) => {
      if (data['return_code'] == '000000') {
        this.regionArray = data['return_data'];
      }
    });
    // 初始化搜索框
    this.searchForm = this.fb.group({
      oilNo: [null],
      executionType: [null],
      regionId: [null],
      merNo: [null],
      merName: [null],
      status: [null],
    });

    this.editTaskForm = this.fb.group({
      priceType: ['1', [Validators.required]],
      regionId: [''],
      oilPriceZoneId: [''],
      oilNo: ['',[Validators.required]],
      price: ['',[Validators.required]],
      executionType: ['',[Validators.required]],
      startTime: [''],
      });
      // 查询数据
    this.queryData();
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.oilTaskService.getTaskList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 删除
   */
  delTask(id: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定删除任务吗？',
      nzOnOk: () =>
        this.oilTaskService.delTask({taskId: id}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 打开编辑任务模态框
   */
  showEditTaskModal() {
    this.editTaskModal = true;
  }

  /**
   * 提交数据
   */
  submitData() {
    if (this.editTaskForm.valid) {
      let param = [];
      param.push(this.editTaskForm.value);
      this.oilTaskService.batchAddTask(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          // 刷新数据
          this.queryData();
          // 关闭弹窗
          this.closeEditTaskModal();
          // 表单重置
          this.editTaskForm.reset();
          this.editTaskForm.controls['priceType'].setValue('1');
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else {
      Object.values(this.editTaskForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭编辑任务模态框
   */
  closeEditTaskModal() {
    this.editTaskModal = false;
  }
}
