import {Component, OnInit} from '@angular/core';
import {OrderOilService} from "../../../services/trade/order-oil.service";
import {FormBuilder, FormGroup, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzModalComponent, NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzMessageService} from "ng-zorro-antd/message";
import {environment} from "../../../../environments/environment";
import {DatePipe, DecimalPipe, NgForOf, NgIf} from "@angular/common";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDatePickerComponent, NzRangePickerComponent} from "ng-zorro-antd/date-picker";
import {NzDescriptionsComponent, NzDescriptionsItemComponent, NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzRadioButtonDirective, NzRadioComponent, NzRadioGroupComponent} from "ng-zorro-antd/radio";
import {NzTabComponent, NzTabSetComponent, NzTabsModule} from "ng-zorro-antd/tabs";
import {DateSelectType, DateUtils} from "../../../utils/dateUtils.service";
import {OrderRefundService} from "../../../services/trade/order-refund.service";
import {NzDropDownDirective, NzDropdownMenuComponent, NzDropDownModule} from "ng-zorro-antd/dropdown";
import {NzIconModule} from "ng-zorro-antd/icon";
import {AgentService} from "../../../services/agent/agent.service";
import {AgentStaffService} from "../../../services/agent/agent-staff.service";
import {NzStatisticModule} from "ng-zorro-antd/statistic";
import {NzCardModule} from "ng-zorro-antd/card";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {DATA} from "../../../data/login/localStorage.namespace";
import {NzSpinComponent, NzSpinModule} from "ng-zorro-antd/spin";
import {NzTimelineComponent, NzTimelineItemComponent} from "ng-zorro-antd/timeline";
import {NzBadgeComponent} from "ng-zorro-antd/badge";
import {ButtonPipe} from "../../../pipes/common/button.pipe";
import {NzTooltipDirective} from "ng-zorro-antd/tooltip";
import {symlinkSync} from "fs";
import {DateMinutesDiffPipe} from "../../../pipes/common/date-minutes-diff.pipe";
import {NzDividerModule} from "ng-zorro-antd/divider";

@Component({
  selector: 'app-order-oil-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDatePickerComponent,
    NzDescriptionsComponent,
    NzDescriptionsItemComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzInputDirective,
    NzModalComponent,
    NzOptionComponent,
    NzRadioButtonDirective,
    NzRadioComponent,
    NzRadioGroupComponent,
    NzRangePickerComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTabComponent,
    NzTabSetComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzModalModule,
    NzDropdownMenuComponent,
    NzDropDownDirective,
    NzDropDownModule,
    NzIconModule,
    NzCardModule,
    NzSpinComponent,
    NzTimelineItemComponent,
    NzTimelineComponent,
    NzBadgeComponent,
    NzTooltipDirective,
    DateMinutesDiffPipe,
    NzDividerModule
  ],
  templateUrl: './order-oil-list.component.html',
  styleUrl: './order-oil-list.component.less'
})
export class OrderOilListComponent {
  loadingObject = {
    title: "加载中...",
    status: false,
  };
  imageUrl = environment.imageUrl;
  // 表单页数
  tablePageNum = 1;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  // 统计数据
  totalData = {
    totalCount: 0,
    totalRefuelPrice: 0,
    totalOilLiters: 0,
    totalActualPayPrice: 0,
  };
  // 搜索表单
  searchForm: FormGroup;
  // 更多搜索条件
  isCollapse = false;
  // 时间类型选择
  dateTypeSelect = DateSelectType;
  // 状态
  statusArray = new DictionaryPipe().getDictionaryList('GAS_ORDER_STATUS');
  // 油号
  oilNoArray = new DictionaryPipe().getDictionaryList('OIL_NO');
  // 支付类型
  payTypeArray = new DictionaryPipe().getDictionaryList('ORDER_PAY_TYPE');
  // 渠道
  channelTypeArray = new DictionaryPipe().getDictionaryList('MER_SOURCE_TYPE');
  // 账户类型
  accountType: number;
  // 代理商账户
  agentAccount: any;
  // 代理商
  agentArray: any = [];
  // 业务员
  agentStaffArray: any = [];
  // 订单详情模态框
  orderDetailModal= false;
  // 订单详情模态框加载
  orderDetailModalLoading= false;
  // 订单详情对象
  orderDetailObject: any = {
    gasOrder: {},
    tradeOrder: {},
  };

  orderRefundModal = false;
  refundForm: FormGroup;
  GAS_REFUND_BTN = new ButtonPipe().isButton("GAS_REFUND");
  GAS_ORDER_PRINT_BTN = new ButtonPipe().isButton("GAS_ORDER_PRINT_BTN");
  GAS_ORDER_REPAIR_BTN = new ButtonPipe().isButton("GAS_ORDER_REPAIR_BTN");
  constructor(private fb: NonNullableFormBuilder,
              private orderOilService : OrderOilService,
              private agentService : AgentService,
              private storage: BrowserStorageService,
              private agentStaffService : AgentStaffService,
              private orderRefundService: OrderRefundService,
              private message: NzMessageService,
              private modal: NzModalService) {
    this.accountType = this.storage.get(DATA)['account']['objectType'];
    this.agentAccount = this.storage.get(DATA)['agent'];

    // 退款提示模态框
    this.refundForm = this.fb.group({
      orderNo: [{ value: null, disabled: true}, [Validators.required]],
      childOrderNo: [{ value: null, disabled: true}, [Validators.required]],
      remarks: [null,[Validators.required]],
    });

    // 初始化搜索框
    this.searchForm = this.fb.group({
      merName: [''],
      userPhone: [''],
      orderNo: [''],
      payType: [''],
      paySerialNo: [''],
      channelType: [''],
      channelOrderNo: [''],
      gasOilNo: [''],
      gasStaffName: [''],
      agentId: [''],
      agentStaffId: [''],
      abnormal: [''],
      status: ['2'],
      createTimeArray: [[]],
      createTimeSelect: ['1'],
      createTimeS: [''],
      createTimeE: [''],
    });
    // 初始化创建时间
    this.createTimeInit();
    // 查询数据
    this.queryData();

    if (this.accountType == 1) {
      // 查询代理商
      this.queryAgent();
    }
    if (this.accountType == 4) {
      // 查询业务员
      this.queryAgentStaff(this.storage.get(DATA)['account']['objectId']);
    }
  }

  /**
   * 获取代理商
   */
  queryAgent() {
    this.agentService.queryAgentList({ pageNum:1,pageSize:999}, (data: any) => {
      this.agentArray = data['return_data']['list'];
      this.agentArray.push({
        id: 0,
        name: '无'
      })
      this.agentArray.sort((a: any, b: any) => a.id - b.id);
    });
  }

  /**
   * 获取业务员
   * @param agentId
   */
  queryAgentStaff(agentId: number) {
    this.searchForm.controls['agentStaffId'].setValue(null);
    this.agentStaffService.getStaffList({ agentId: agentId,pageNum:1,pageSize:999}, (data: any) => {
      this.agentStaffArray = data['return_data']['list'];
    });
  }
  /**
   * 获取数据
   */
  queryData() {
    if (this.searchForm.controls['createTimeArray'].value != null
      && this.searchForm.controls['createTimeArray'].value.length > 0) {
      this.searchForm.controls['createTimeS'].setValue(new Date(this.searchForm.controls['createTimeArray'].value[0]).getTime());
      this.searchForm.controls['createTimeE'].setValue(new Date(this.searchForm.controls['createTimeArray'].value[1]).getTime());
    } else {
      this.searchForm.controls['createTimeS'].setValue(null);
      this.searchForm.controls['createTimeE'].setValue(null);
    }
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = 10;
    this.searchForm.value.time = new Date().getTime();
    // 查询订单列表
    this.orderOilService.queryList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
        for (let data of this.tableData['list']) {
          if (data['abnormal'] == 1) {
            data['color'] = 'red';
          }
        }
      }
    });
    // 查询统计
    this.orderOilService.countOilData(this.searchForm.value,(data: any) => {
      if (data['return_code'] == '000000') {
        this.totalData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 创建时间初始化
   */
  createTimeInit() {
    let createTimeSelect = this.searchForm.controls['createTimeSelect'].value;
    if (createTimeSelect != null) {
      let timeObj = DateUtils.getDate(new Date(), Number(createTimeSelect));
      this.searchForm.controls['createTimeArray'].setValue([timeObj.timeS, timeObj.timeE]);
    }
  }

  /**
   * 导出加油订单
   */
  exportOilOrder() {
    this.orderOilService.exportOilOrder(this.searchForm.value, (data:any) => {
      window.location.href = this.imageUrl + 'temporary/' + data['return_data'];
    });
  }

  /**
   * 补单确认框
   * @param orderNo
   */
  showRepairOrder(orderNo: string) {
    this.modal.confirm({
      nzTitle: '补单提示',
      nzContent: '交易单号：' + orderNo + '，是否重新推送订单到渠道？',
      nzOnOk: () => this.submitRepairOrder(orderNo)
    });
  }

  /**
   * 提交补单
   */
  submitRepairOrder(orderNo: string) {
    this.orderOilService.repairOrder(orderNo, (data: any) => {
      if (data['return_code'] == '000000') {
        this.message.success("操作成功");
        this.queryData();
      } else {
        this.message.create('error', data['return_msg']);
      }
    });
  }

  /**
   * 打开详情模态框
   * @param orderNo
   */
  showOrderDetail(orderNo: string) {
    this.orderDetailModalLoading = true;
    this.orderOilService.queryOilOrder(orderNo, (data:any) => {
      this.orderDetailObject = data['return_data'];
      this.orderDetailModalLoading = false;
    });
    this.orderDetailModal = true;
  }

  /**
   * 关闭详情模态框
   */
  closeOrderDetail() {
    this.orderDetailModal = false;
  }

  /**
   * 打开退款模态框
   * @param orderNo
   * @param childOrderNo
   */
  showRefund(orderNo: string, childOrderNo: string) {
    this.refundForm.patchValue({ orderNo: orderNo, childOrderNo: childOrderNo})
    this.orderRefundModal = true;
  }

  /**
   * 关闭退款模态框
   */
  closeRefund() {
    this.orderRefundModal = false;
  }

  /**
   * 提交退款
   * @param orderNo
   */
  submitRefundConfirm() {
    for (const i in this.refundForm.controls) {
      this.refundForm.controls[i].markAsDirty();
      this.refundForm.controls[i].updateValueAndValidity();
    }
    if (this.refundForm.status == null || this.refundForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请填写所有必填项',
      });
      return;
    }
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定对交易订号（'+this.refundForm.controls['orderNo'].value+'）进行退款吗？',
      nzOnOk: () => this.submitRefund()
    });
  }

  /**
   * 提交退款
   * @param orderNo
   */
  submitRefund() {
    this.loadingObject.status = true;
    this.loadingObject.title = '处理中...';
    this.orderRefundService.tradeOrderChild(this.refundForm.controls['childOrderNo'].value,1, this.refundForm.controls['remarks'].value, (data: any) => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '操作成功',
        });
        this.queryData();
        this.closeRefund();
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
      this.loadingObject.status = false;
    });
    this.orderRefundModal = true;
  }

  /**
   * 订单打印提示
   */
  showOrderPrint(orderNo: string) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '是否补打小票？',
      nzOnOk: () => this.submitOrderPrint(orderNo)
    });
  }

  /**
   * 提交订单打印
   */
  submitOrderPrint(orderNo: string) {
    this.orderOilService.printOrder(orderNo, (data: any) => {
      if (data['return_code'] === '000000') {
        this.message.success("操作成功");
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
    })
  }
}
